@@ -52,14 +52,14 @@ lcd = CommandGeneratorLcdConfigurator()
 isEndOfMib = lambda x: not cmdgen.getNextVarBinds(x)[1]
 
 
-@asyncio.coroutine
-def getCmd(snmpEngine, authData, transportTarget, contextData,
+
+async def getCmd(snmpEngine, authData, transportTarget, contextData,
            *varBinds, **options):
     r"""Creates a generator to perform SNMP GET query.
 
     When iterator gets advanced by :py:mod:`asyncio` main loop,
     SNMP GET request is send (:RFC:`1905#section-4.2.1`).
-    The iterator yields :py:class:`asyncio.Future` which gets done whenever
+    The iterator yields :py:class:`asyncio.get_running_loop().create_future()` which gets done whenever
     response arrives or error occurs.
 
     Parameters
@@ -111,15 +111,15 @@ def getCmd(snmpEngine, authData, transportTarget, contextData,
     >>> import asyncio
     >>> from pysnmp.hlapi.asyncio import *
     >>>
-    >>> @asyncio.coroutine
-    ... def run():
-    ...     errorIndication, errorStatus, errorIndex, varBinds = yield from getCmd(
+    >>> async def run():
+    ...     result_get = await getCmd(
     ...         SnmpEngine(),
     ...         CommunityData('public'),
     ...         UdpTransportTarget(('demo.snmplabs.com', 161)),
     ...         ContextData(),
     ...         ObjectType(ObjectIdentity('SNMPv2-MIB', 'sysDescr', 0))
     ...     )
+    ...     errorIndication, errorStatus, errorIndex, varBinds = await result_get
     ...     print(errorIndication, errorStatus, errorIndex, varBinds)
     >>>
     >>> asyncio.get_event_loop().run_until_complete(run())
@@ -148,7 +148,7 @@ def getCmd(snmpEngine, authData, transportTarget, contextData,
     addrName, paramsName = lcd.configure(
         snmpEngine, authData, transportTarget, contextData.contextName)
 
-    future = asyncio.Future()
+    future = asyncio.get_running_loop().create_future()
 
     cmdgen.GetCommandGenerator().sendVarBinds(
         snmpEngine, addrName, contextData.contextEngineId,
@@ -159,14 +159,13 @@ def getCmd(snmpEngine, authData, transportTarget, contextData,
     return future
 
 
-@asyncio.coroutine
-def setCmd(snmpEngine, authData, transportTarget, contextData,
+async def setCmd(snmpEngine, authData, transportTarget, contextData,
            *varBinds, **options):
     r"""Creates a generator to perform SNMP SET query.
 
     When iterator gets advanced by :py:mod:`asyncio` main loop,
     SNMP SET request is send (:RFC:`1905#section-4.2.5`).
-    The iterator yields :py:class:`asyncio.Future` which gets done whenever
+    The iterator yields :py:class:`asyncio.get_running_loop().create_future()` which gets done whenever
     response arrives or error occurs.
 
     Parameters
@@ -218,9 +217,8 @@ def setCmd(snmpEngine, authData, transportTarget, contextData,
     >>> import asyncio
     >>> from pysnmp.hlapi.asyncio import *
     >>>
-    >>> @asyncio.coroutine
-    ... def run():
-    ...     errorIndication, errorStatus, errorIndex, varBinds = yield from setCmd(
+    >>> async def run():
+    ...     errorIndication, errorStatus, errorIndex, varBinds = yield setCmd(
     ...         SnmpEngine(),
     ...         CommunityData('public'),
     ...         UdpTransportTarget(('demo.snmplabs.com', 161)),
@@ -255,7 +253,7 @@ def setCmd(snmpEngine, authData, transportTarget, contextData,
     addrName, paramsName = lcd.configure(
         snmpEngine, authData, transportTarget, contextData.contextName)
 
-    future = asyncio.Future()
+    future = asyncio.get_running_loop().create_future()
 
     cmdgen.SetCommandGenerator().sendVarBinds(
         snmpEngine, addrName, contextData.contextEngineId,
@@ -266,14 +264,13 @@ def setCmd(snmpEngine, authData, transportTarget, contextData,
     return future
 
 
-@asyncio.coroutine
-def nextCmd(snmpEngine, authData, transportTarget, contextData,
+async def nextCmd(snmpEngine, authData, transportTarget, contextData,
             *varBinds, **options):
     r"""Creates a generator to perform SNMP GETNEXT query.
 
     When iterator gets advanced by :py:mod:`asyncio` main loop,
     SNMP GETNEXT request is send (:RFC:`1905#section-4.2.2`).
-    The iterator yields :py:class:`asyncio.Future` which gets done whenever
+    The iterator yields :py:class:`asyncio.get_running_loop().create_future()` which gets done whenever
     response arrives or error occurs.
 
     Parameters
@@ -329,9 +326,8 @@ def nextCmd(snmpEngine, authData, transportTarget, contextData,
     >>> import asyncio
     >>> from pysnmp.hlapi.asyncio import *
     >>>
-    >>> @asyncio.coroutine
-    ... def run():
-    ...     errorIndication, errorStatus, errorIndex, varBinds = yield from nextCmd(
+    >>> async def run():
+    ...     errorIndication, errorStatus, errorIndex, varBinds = yield nextCmd(
     ...         SnmpEngine(),
     ...         CommunityData('public'),
     ...         UdpTransportTarget(('demo.snmplabs.com', 161)),
@@ -368,7 +364,7 @@ def nextCmd(snmpEngine, authData, transportTarget, contextData,
     addrName, paramsName = lcd.configure(
         snmpEngine, authData, transportTarget, contextData.contextName)
 
-    future = asyncio.Future()
+    future = asyncio.get_running_loop().create_future()
 
     cmdgen.NextCommandGenerator().sendVarBinds(
         snmpEngine, addrName, contextData.contextEngineId,
@@ -379,14 +375,13 @@ def nextCmd(snmpEngine, authData, transportTarget, contextData,
     return future
 
 
-@asyncio.coroutine
-def bulkCmd(snmpEngine, authData, transportTarget, contextData,
+async def bulkCmd(snmpEngine, authData, transportTarget, contextData,
             nonRepeaters, maxRepetitions, *varBinds, **options):
     r"""Creates a generator to perform SNMP GETBULK query.
 
     When iterator gets advanced by :py:mod:`asyncio` main loop,
     SNMP GETBULK request is send (:RFC:`1905#section-4.2.3`).
-    The iterator yields :py:class:`asyncio.Future` which gets done whenever
+    The iterator yields :py:class:`asyncio.get_running_loop().create_future()` which gets done whenever
     response arrives or error occurs.
 
     Parameters
@@ -470,9 +465,8 @@ def bulkCmd(snmpEngine, authData, transportTarget, contextData,
     >>> import asyncio
     >>> from pysnmp.hlapi.asyncio import *
     >>>
-    >>> @asyncio.coroutine
-    ... def run():
-    ...     errorIndication, errorStatus, errorIndex, varBinds = yield from bulkCmd(
+    >>> async def run():
+    ...     result_bulk = await bulkCmd(
     ...         SnmpEngine(),
     ...         CommunityData('public'),
     ...         UdpTransportTarget(('demo.snmplabs.com', 161)),
@@ -480,9 +474,10 @@ def bulkCmd(snmpEngine, authData, transportTarget, contextData,
     ...         0, 2,
     ...         ObjectType(ObjectIdentity('SNMPv2-MIB', 'system'))
     ...     )
+    ...     errorIndication, errorStatus, errorIndex, varBinds = await result_bulk
     ...     print(errorIndication, errorStatus, errorIndex, varBinds)
     >>>
-    >>> asyncio.get_event_loop().run_until_complete(run())
+    >>> asyncio.run(run())
     (None, 0, 0, [[ObjectType(ObjectIdentity(ObjectName('1.3.6.1.2.1.1.1.0')), DisplayString('SunOS zeus.snmplabs.com 4.1.3_U1 1 sun4m'))], [ObjectType(ObjectIdentity(ObjectName('1.3.6.1.2.1.1.2.0')), ObjectIdentifier('1.3.6.1.4.1.424242.1.1'))]])
     >>>
 
@@ -510,7 +505,7 @@ def bulkCmd(snmpEngine, authData, transportTarget, contextData,
     addrName, paramsName = lcd.configure(
         snmpEngine, authData, transportTarget, contextData.contextName)
 
-    future = asyncio.Future()
+    future = asyncio.get_running_loop().create_future()
 
     cmdgen.BulkCommandGenerator().sendVarBinds(
         snmpEngine, addrName, contextData.contextEngineId,
